@@ -31,7 +31,9 @@ typedef enum {
   CONF_SHOW_TOOLBAR,
   CONF_CLICK_TO_MOVE,
   CONF_SOUND,
-  CONF_STATISTICS
+  CONF_SHOW_STATUSBAR,
+  CONF_ANIMATIONS,
+  CONF_STATISTICS /* must be last */
 } AisleriotConfKey;
 
 typedef struct {
