@@ -22,7 +22,6 @@
 #include <config.h>
 
 #include <string.h>
-#include <locale.h>
 
 #include <libguile.h>
 
@@ -33,6 +32,7 @@
 
 #ifdef HAVE_CLUTTER
 #include <clutter/clutter.h>
+#include <clutter-gtk/clutter-gtk.h>
 #endif
 
 #ifdef HAVE_HILDON
@@ -56,10 +56,12 @@
 #define HELP_EXT "xhtml"
 #endif /* G_OS_WIN32 */
 
+#include <libgames-support/games-debug.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
+#include <libgames-support/games-string-utils.h>
 
 #ifdef WITH_SMCLIENT
 #include <libgames-support/eggsmclient.h>
@@ -70,10 +72,6 @@
 #include "util.h"
 #include "window.h"
 
-#ifdef HAVE_CLUTTER
-#include "clutter-embed.h"
-#endif
-
 typedef struct {
   AisleriotWindow *window;
   char *variation;
@@ -85,9 +83,11 @@ typedef struct {
 #endif /* HAVE_HILDON */
 } AppData;
 
+#if !GTK_CHECK_VERSION (2, 17, 0)
+
 static void
 about_url_hook (GtkAboutDialog *about,
-                const char *link,
+                const char *uri,
                 gpointer user_data)
 {
 #if defined(HAVE_MAEMO)
@@ -97,11 +97,11 @@ about_url_hook (GtkAboutDialog *about,
                               "osso_browser",
                               OSSO_BROWSER_OPEN_NEW_WINDOW_REQ,
                               NULL,
-                              DBUS_TYPE_STRING, link,
+                              DBUS_TYPE_STRING, uri,
                               DBUS_TYPE_INVALID);
 
 #elif defined (G_OS_WIN32)
-  ShellExecute( NULL, "open", link, NULL, NULL, SW_SHOWNORMAL ); 
+  ShellExecute( NULL, "open", uri, NULL, NULL, SW_SHOWNORMAL );
 #else
 
   GdkScreen *screen;
@@ -109,7 +109,7 @@ about_url_hook (GtkAboutDialog *about,
 
   screen = gtk_widget_get_screen (GTK_WIDGET (about));
 
-  if (!gtk_show_uri (screen, link, gtk_get_current_event_time (), &error)) {
+  if (!gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error)) {
     GtkWidget *dialog;
 
     dialog = gtk_message_dialog_new (GTK_WINDOW (about),
@@ -140,7 +140,12 @@ about_email_hook (GtkAboutDialog *about,
 {
   char *escaped, *uri;
 
+#if GLIB_CHECK_VERSION (2, 16, 0)
   escaped = g_uri_escape_string (email_address, NULL, FALSE);
+#else
+  /* Not really correct, but the best we can do */
+  escaped = g_strdup (email_address);
+#endif
   uri = g_strdup_printf ("mailto:%s", escaped);
   g_free (escaped);
 
@@ -148,6 +153,8 @@ about_email_hook (GtkAboutDialog *about,
   g_free (uri);
 }
 
+#endif /* GTK < 2.17.0 */
+
 static char *
 variation_to_game_file (const char *variation)
 {
@@ -362,7 +369,7 @@ help_hook (GtkWindow *parent,
     if (game_file != NULL) {
       char *game_name;
  
-      game_name = aisleriot_util_get_display_filename (game_file);
+      game_name = games_filename_to_display_name (game_file);
       primary = g_strdup_printf (_("Could not show help for “%s”"), game_name);
       g_free (game_name);
     } else {
@@ -540,7 +547,6 @@ main_prog (void *closure, int argc, char *argv[])
   add_main_options (option_context, &data);
 
   games_sound_enable (FALSE);
-  games_sound_add_option_group (option_context);
 
   g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
 #ifdef WITH_SMCLIENT
@@ -560,7 +566,7 @@ main_prog (void *closure, int argc, char *argv[])
   }
 
 #ifdef HAVE_CLUTTER
-  if (aisleriot_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
+  if (gtk_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
     g_printerr ("Failed to initialise clutter: %s\n", error->message);
     g_error_free (error);
     goto cleanup;
@@ -601,8 +607,10 @@ main_prog (void *closure, int argc, char *argv[])
 
   aisleriot_util_set_help_func (help_hook, &data);
 
+#if !GTK_CHECK_VERSION (2, 17, 0)
   gtk_about_dialog_set_url_hook (about_url_hook, &data, NULL);
   gtk_about_dialog_set_email_hook (about_email_hook, &data, NULL);
+#endif
 
   data.window = AISLERIOT_WINDOW (aisleriot_window_new ());
   g_signal_connect (data.window, "destroy",
@@ -656,14 +664,14 @@ main_prog (void *closure, int argc, char *argv[])
 
   aisleriot_conf_shutdown ();
 
-  cleanup:
-  g_free (data.variation);
-
 #ifdef WITH_SMCLIENT
   g_signal_handlers_disconnect_matched (sm_client, G_SIGNAL_MATCH_DATA,
                                         0, 0, NULL, NULL, &data);
 #endif /* WITH_SMCLIENT */
 
+cleanup:
+  g_free (data.variation);
+
 #ifdef HAVE_MAEMO
   if (data.program != NULL) {
     g_object_unref (data.program);
@@ -679,22 +687,9 @@ main_prog (void *closure, int argc, char *argv[])
 int
 main (int argc, char *argv[])
 {
-  setlocale (LC_ALL, "");
-
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS) || defined(HAVE_GSTREAMER)
-  /* If we're going to use gnome-vfs or gstreamer, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("aisleriot"))
     return 1;
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   scm_boot_guile (argc, argv, main_prog, NULL); /* no return */
 
   return 0;
