@@ -1,3 +1,4 @@
+gchar *s = N_("Accordion")
 gchar *s = N_("Agnes")
 gchar *s = N_("Athena")
 gchar *s = N_("Auld Lang Syne")
@@ -30,6 +31,7 @@ gchar *s = N_("Fourteen")
 gchar *s = N_("Freecell")
 gchar *s = N_("Gaps")
 gchar *s = N_("Gay Gordons")
+gchar *s = N_("Giant")
 gchar *s = N_("Glenwood")
 gchar *s = N_("Gold Mine")
 gchar *s = N_("Golf")
@@ -69,6 +71,7 @@ gchar *s = N_("Straight Up")
 gchar *s = N_("Streets And Alleys")
 gchar *s = N_("Template")
 gchar *s = N_("Ten Across")
+gchar *s = N_("Terrace")
 gchar *s = N_("Thieves")
 gchar *s = N_("Thirteen")
 gchar *s = N_("Thumb And Pouch")
