@@ -109,6 +109,11 @@ class ChessPiece(glchess.scene.ChessPiece):
 
     def move(self, coord, delete, animate = True):
         """Extends glchess.scene.ChessPiece"""
+        if not coord:
+            self.scene.pieces.remove(self)
+            self.feedback.onDeleted()
+            return
+
         self.delete = delete
         self.location = coord
         self.targetPos = self.scene._coordToLocation(coord)
@@ -306,7 +311,7 @@ class Scene(glchess.scene.Scene):
         glViewport(0, 0, self.viewportWidth, self.viewportHeight)
         self.feedback.onRedraw()
 
-    def setBoardRotation(self, angle, animate = True):
+    def setBoardRotation(self, angle, faceToFace = False, animate = True):
         """Set the rotation on the board.
         
         'angle' is the angle the board should be drawn at in degress (float, [0.0, 360.0]).
