@@ -1,4 +1,5 @@
-import gtk, gtk.glade, gobject
+# -*- coding: utf-8 -*-
+import gtk, gobject
 import sudoku
 from gtk_goodies import gconf_wrapper
 from defaults import *
@@ -8,7 +9,7 @@ import threading
 
 class GameGenerator (gconf_wrapper.GConfWrapper):
 
-    glade_file = os.path.join(GLADE_DIR,'puzzle_generator.glade')
+    ui_file = os.path.join(UI_DIR,'puzzle_generator.ui')
 
     initial_prefs = {'generate_target_easy':1,
                      'generate_target_medium':0,
@@ -18,49 +19,52 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
                      'generate_for_target':0,
                      'number_of_sudokus_to_generate':10,
                      }
-    
+
     def __init__ (self, UI, gconf):
         self.ui = UI
-        self.sudoku_tracker = self.ui.sudoku_tracker
         self.sudoku_maker = self.ui.sudoku_maker
         # Don't work in background...
         self.ui.stop_worker_thread()
         gconf_wrapper.GConfWrapper.__init__(self,gconf)
-        self.glade = gtk.glade.XML(self.glade_file)
+        self.builder = gtk.Builder()
+        self.builder.add_from_file(self.ui_file)
         self.generate_for_target_widgets = []
+        self.cat_to_label = {}
         for d in ['easy',
                   'medium',
                   'hard',
                   'veryHard']:
             widget_name = '%sCheckButton'%d
-            widget = self.glade.get_widget(widget_name)
+            widget = self.builder.get_object(widget_name)
             label_widget_name = '%sLabel'%d
-            setattr(self,label_widget_name,self.glade.get_widget(label_widget_name))
+            setattr(self,label_widget_name,self.builder.get_object(label_widget_name))
             setattr(self,widget_name,widget)
             gconf_setting = 'generate_target_%s'%d
             self.gconf_wrap_toggle(gconf_setting,widget)
             self.generate_for_target_widgets.append(widget)
-        self.generateEndlesslyRadio = self.glade.get_widget('generateEndlesslyRadio')
-        self.generateForTargetRadio = self.glade.get_widget('generateForTargetRadio')
+            self.cat_to_label[d] = getattr(self,label_widget_name)
+        self.cat_to_label['very hard'] = self.cat_to_label['veryHard']
+        self.generateEndlesslyRadio = self.builder.get_object('generateEndlesslyRadio')
+        self.generateForTargetRadio = self.builder.get_object('generateForTargetRadio')
         self.gconf_wrap_toggle('generate_endlessly',self.generateEndlesslyRadio)
         self.gconf_wrap_toggle('generate_for_target',self.generateForTargetRadio)
         self.generateEndlesslyRadio.connect('toggled',self.generate_method_changed_cb)
-        self.newSudokusSpinButton = self.glade.get_widget('newSudokusSpinButton')
+        self.newSudokusSpinButton = self.builder.get_object('newSudokusSpinButton')
         self.gconf_wrap_adjustment('number_of_sudokus_to_generate',
                                    self.newSudokusSpinButton.get_adjustment()
                                    )
         self.generate_for_target_widgets.append(self.newSudokusSpinButton)
-        self.generateButton = self.glade.get_widget('generateButton')
+        self.generateButton = self.builder.get_object('generateButton')
         self.generateButton.connect('clicked',self.generate_cb)
-        self.closeButton = self.glade.get_widget('closeButton')
+        self.closeButton = self.builder.get_object('closeButton')
         self.closeButton.connect('clicked',self.close_cb)
-        self.pauseButton = self.glade.get_widget('pauseButton')
+        self.pauseButton = self.builder.get_object('pauseButton')
         self.pauseButton.connect('clicked',self.pause_cb)
-        self.stopButton = self.glade.get_widget('stopButton')
+        self.stopButton = self.builder.get_object('stopButton')
         self.stopButton.connect('clicked',self.stop_cb)
         self.pauseButton.set_sensitive(False)
         self.stopButton.set_sensitive(False)
-        self.prog = self.glade.get_widget('progressbar1')
+        self.prog = self.builder.get_object('progressbar1')
         self.prog.set_text('0 %')
         self.working = False
         self.easyCheckButton.connect('clicked',self.criteria_cb)
@@ -68,10 +72,12 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         self.hardCheckButton.connect('clicked',self.criteria_cb)
         self.veryHardCheckButton.connect('clicked',self.criteria_cb)
         self.generate_method_changed_cb()
-        self.dialog = self.glade.get_widget('PuzzleGenerator')
+        self.dialog = self.builder.get_object('PuzzleGenerator')
         self.dialog.show_all()
+        self.dialog.set_transient_for(self.ui.w)
         self.dialog.present()
-        self.setup_base_status()
+        self.update_available()
+        self.initally_generated = self.sudoku_maker.n_puzzles()
 
     def generate_method_changed_cb (self, *args):
         if not self.generateForTargetRadio.get_active():
@@ -94,8 +100,7 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
             self.generateButton.set_sensitive(False)
 
     def generate_cb (self, *args):
-        self.ngenerated = 0
-        self.toward_target = 0
+        self.initally_generated = self.sudoku_maker.n_puzzles()
         self.pauseButton.set_sensitive(True)
         self.stopButton.set_sensitive(True)
         self.generateButton.set_sensitive(False)
@@ -138,68 +143,32 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         self.dialog.hide()
         self.dialog.destroy()
 
-    def setup_base_status (self):
+    def update_available (self):
         """Setup basic status.
         """
-        for puzz,diff in self.sudoku_tracker.list_new_puzzles():
-            diffstr = diff.value_string()
-            if diffstr == sudoku.DifficultyRating.easy:
-                self.increment_label(self.easyLabel)
-            elif diffstr == sudoku.DifficultyRating.medium:
-                self.increment_label(self.mediumLabel)
-            elif diffstr == sudoku.DifficultyRating.hard:
-                self.increment_label(self.hardLabel)
-            else:
-                self.increment_label(self.veryHardLabel)
+        for diff,lab in [('easy',self.easyLabel),
+                         ('medium',self.mediumLabel),
+                         ('hard',self.hardLabel),
+                         ('very hard',self.veryHardLabel)]:
+            num = self.sudoku_maker.n_puzzles(diff)
+            lab.set_text(ngettext("%(n)s puzzle","%(n)s puzzles",num)%{'n':num})
 
-    def increment_label (self, lab, val=1):
-        curtext = lab.get_text()
-        if not curtext:
-            newval = val
-        else:
-            curval = int(curtext.split()[0])
-            newval = curval + val
-        newtext = ngettext("%(n)s puzzle","%(n)s puzzles",newval)%{'n':newval}
-        lab.set_text(newtext)
+    def generated (self):
+        return self.sudoku_maker.n_puzzles() - self.initally_generated
 
     def update_status (self, *args):
         """Update status of our progress bar and puzzle table.
         """
-        npuzzles = len(self.sudoku_maker.new_puzzles)
-        if npuzzles > self.ngenerated:
-            # updating gui...
-            to_add = self.sudoku_maker.new_puzzles[self.ngenerated:]
-            self.ngenerated=npuzzles
-            for puzz,diff in to_add:
-                diffstr = diff.value_string()
-                if diffstr == sudoku.DifficultyRating.easy:
-                    self.increment_label(self.easyLabel)
-                    if (not self.generateForTargetRadio.get_active() or
-                        self.easyCheckButton.get_active()):
-                        self.toward_target += 1
-                elif diffstr == sudoku.DifficultyRating.medium:
-                    self.increment_label(self.mediumLabel)
-                    if (not self.generateForTargetRadio.get_active() or
-                        self.mediumCheckButton.get_active()):
-                        self.toward_target += 1
-                elif diffstr == sudoku.DifficultyRating.hard:                    
-                    self.increment_label(self.hardLabel)
-                    if (not self.generateForTargetRadio.get_active() or
-                        self.hardCheckButton.get_active()):
-                        self.toward_target += 1
-                else:
-                    self.increment_label(self.veryHardLabel)
-                    if (not self.generateForTargetRadio.get_active() or
-                        self.veryHardCheckButton.get_active()):
-                        self.toward_target += 1
-            if (self.generateForTargetRadio.get_active()
-                and
-                self.newSudokusSpinButton.get_value()<=self.toward_target):
-                self.toward_target=int(self.newSudokusSpinButton.get_value())
-                self.update_progress_bar()
-                self.stop_cb()
-                return False
-            self.update_progress_bar()
+        #print 'update_status!'
+        self.update_available()
+        self.update_progress_bar()
+        if (self.generateForTargetRadio.get_active()
+            and
+            self.generated()>=int(self.newSudokusSpinButton.get_value())
+            ):
+            print 'Done!'
+            self.stop_cb()
+            return False
         if self.paused: self.prog.set_text(_('Paused'))
         elif self.generateEndlesslyRadio.get_active():
             self.prog.pulse()
@@ -217,12 +186,12 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
         if self.generateForTargetRadio.get_active():
             tot = int(self.newSudokusSpinButton.get_value())
             self.prog.set_fraction(
-                float(self.toward_target)/tot
+                float(self.generated())/tot
                 )
             try:
                 txt = ngettext('Generated %(n)s out of %(total)s puzzle',
                                'Generated %(n)s out of %(total)s puzzles',
-                               tot)%{'n':self.toward_target,'total':tot}
+                               tot)%{'n':self.generated(),'total':tot}
             except TypeError:
                 # Allow for fuzzy translation badness caused by a
                 # previous version having this done the wrong way
@@ -232,13 +201,13 @@ class GameGenerator (gconf_wrapper.GConfWrapper):
                 try:
                     txt = ngettext('Generated %(n)s out of %(total)s puzzle',
                                    'Generated %(n)s out of %(total)s puzzles',
-                                   tot)%(self.toward_target,tot)
+                                   tot)%(self.generated(),tot)
                 except:
                     # Fallback to English
-                    txt = 'Generated %s out of %s puzzles'%(self.toward_target,tot)
+                    txt = 'Generated %s out of %s puzzles'%(self.generated(),tot)
         else:
             self.prog.pulse()
-            txt = ngettext('Generated %(n)s puzzle','Generated %(n)s puzzles',self.toward_target)%{'n':self.toward_target}
+            txt = ngettext('Generated %(n)s puzzle','Generated %(n)s puzzles',self.generated())%{'n':self.generated()}
         if self.paused: txt = txt + ' (' + _('Paused') + ')'
         self.prog.set_text(txt)
 
