@@ -39,20 +39,12 @@
 #include <libgames-support/games-stock.h>
 
 #include "tetris.h"
-#include "blockops.h"
 #include "blocks.h"
 #include "scoreframe.h"
 #include "highscores.h"
-
-#ifdef HAVE_CLUTTER
 #include "preview.h"
-#include "field.h"
 #include "renderer.h"
-#else
-#include "preview-noclutter.h"
-#include "field-noclutter.h"
-#include "renderer-noclutter.h"
-#endif
+#include "blockops.h"
 
 int LINES = 20;
 int COLUMNS = 14;
@@ -82,7 +74,6 @@ enum {
 	RESET
 };
 
-
 Tetris::Tetris(int cmdlLevel):
 	themeno (0),
 	field(0),
@@ -90,7 +81,6 @@ Tetris::Tetris(int cmdlLevel):
 	timeoutId(0),
 	onePause(false),
 	inPlay(false),
-	useTarget(false),
 	bgimage(0),
 	setupdialog(0),
 	cmdlineLevel(cmdlLevel),
@@ -187,8 +177,7 @@ Tetris::Tetris(int cmdlLevel):
 	games_conf_add_window (GTK_WINDOW (w), KEY_SAVED_GROUP);
 
 	preview = new Preview ();
-	field = new Field();
-	field->setUseTarget (false);
+	field = new BlockOps ();
 
 	initOptions ();
 
@@ -259,6 +248,7 @@ Tetris::Tetris(int cmdlLevel):
 	gtk_widget_show(vb2);
 	gtk_widget_show(aspect_frame);
 	gtk_widget_show(field->getWidget());
+	gtk_widget_show(preview->getWidget());
 	scoreFrame->show();
 	gtk_widget_show(w);
 
@@ -277,6 +267,7 @@ Tetris::~Tetris()
 	delete field;
 	delete preview;
 	delete scoreFrame;
+	delete high_scores;
 
 	if (bgimage)
 		g_object_unref (G_OBJECT (bgimage));
@@ -439,8 +430,6 @@ Tetris::initOptions ()
 
 	games_sound_enable (confGetBoolean (KEY_OPTIONS_GROUP, KEY_SOUND, TRUE));
 
-	useTarget = confGetBoolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET, FALSE);
-
 	do_preview = confGetBoolean (KEY_OPTIONS_GROUP, KEY_DO_PREVIEW, TRUE);
 
 	if (preview) {
@@ -491,7 +480,6 @@ Tetris::setOptions ()
 
 		if (theme_preview) {
 			theme_preview->setTheme (themeno);
-			gtk_widget_queue_draw(theme_preview->getWidget());
 		}
 	}
 
@@ -540,19 +528,6 @@ Tetris::setSelection(GtkWidget *widget, void *data)
 			       ThemeTable[t->themeno].id);
 }
 
-void
-Tetris::setTarget (GtkWidget *widget, void *data)
-{
-	Tetris *t;
-
-	t = (Tetris *)data;
-
-	t->useTarget = GTK_TOGGLE_BUTTON (widget)->active;
-
-	games_conf_set_boolean (KEY_OPTIONS_GROUP, KEY_USE_TARGET,
-				t->useTarget);
-}
-
 void
 Tetris::lineFillHeightChanged (GtkWidget *spin, gpointer data)
 {
@@ -728,10 +703,6 @@ Tetris::gameProperties(GtkAction *action, void *d)
 			    0, 0, 0);
 
 	t->useTargetToggle = gtk_check_button_new_with_mnemonic (_("Show _where the block will land"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (t->useTargetToggle),
-				      t->useTarget);
-	g_signal_connect (t->useTargetToggle, "clicked",
-			  G_CALLBACK (setTarget), d);
  	gtk_box_pack_start (GTK_BOX (fvbox), t->useTargetToggle,
 			    0, 0, 0);
 
@@ -795,7 +766,7 @@ Tetris::gameProperties(GtkAction *action, void *d)
 	t->theme_preview->setTheme (t->themeno);
 	gtk_box_pack_start(GTK_BOX(fvbox), t->theme_preview->getWidget(), TRUE, TRUE, 0);
 
-	t->theme_preview->previewBlock(4, 0, 0);
+	t->theme_preview->previewBlock(4, 0);
 
 	gtk_widget_show_all (t->setupdialog);
 	gtk_action_set_sensitive(t->new_game_action, FALSE);
@@ -894,14 +865,12 @@ Tetris::timeoutHandler(void *d)
 	if (t->onePause)
 	{
 		t->onePause = false;
-		t->field->redraw();
+		t->field->drawMessage();
 	}
 	else
 	{
 		bool res = t->field->moveBlockDown();
 
-		t->field->redraw();
-
 		if (res)
 		{
 			t->manageFallen();
@@ -965,8 +934,6 @@ Tetris::keyPressHandler(GtkWidget *widget, GdkEvent *event, Tetris *t)
 		}
 	}
 
-	t->field->redraw();
-
 	return res;
 }
 
@@ -1076,7 +1043,7 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 {
 	const char *fileuri;
 
-	GError *error;
+	GError *error = NULL;
 	GFile *file;
 	GFile *outfile;
 	GFileInfo *fileinfo;
@@ -1215,9 +1182,8 @@ Tetris::generate()
 {
 	if (field->generateFallingBlock())
 	{
-		field->putBlockInField(false);
-		preview->previewBlock(blocknr_next, rot_next, color_next);
-		gtk_widget_queue_draw(preview->getWidget());
+		field->putBlockInField(FALLING);
+		preview->previewBlock(blocknr_next, color_next);
 		onePause = true;
 	}
 	else
@@ -1241,8 +1207,7 @@ Tetris::endOfGame()
 	color_next = -1;
 	blocknr_next = -1;
 	rot_next = -1;
-	preview->previewBlock(-1, -1, -1);
-	gtk_widget_queue_draw(preview->getWidget());
+	preview->previewBlock(-1, -1);
 	field->hidePauseMessage();
 	field->showGameOverMessage();
 	games_sound_play ("gameover");
@@ -1253,8 +1218,6 @@ Tetris::endOfGame()
 		int pos = high_scores->add (scoreFrame->getScore());
 		high_scores->show (GTK_WINDOW (w), pos);
 	}
-
-	field->setUseTarget (false);
 }
 
 int
@@ -1282,8 +1245,6 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->scoreFrame->setLevel(level);
 	t->scoreFrame->setStartingLevel(level);
 
-	t->field->setUseTarget (t->useTarget);
-
 	t->generateTimer (level);
 	t->field->emptyField(t->line_fill_height,t->line_fill_prob);
 
@@ -1291,9 +1252,8 @@ Tetris::gameNew(GtkAction *action, void *d)
 	t->paused = false;
 
 	t->field->generateFallingBlock();
-	t->field->redraw();
-	t->preview->previewBlock(blocknr_next, rot_next, color_next);
-	gtk_widget_queue_draw(t->preview->getWidget());
+	t->field->putBlockInField(FALLING);
+	t->preview->previewBlock(blocknr_next, color_next);
 
 	gtk_action_set_visible(t->pause_action, TRUE);
 	gtk_action_set_visible(t->resume_action, FALSE);
@@ -1336,7 +1296,7 @@ Tetris::gameAbout(GtkAction *action, void *d)
 #endif
 			       "version", VERSION,
 			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
-			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2008 Others",
+			       "copyright", "Copyright \xc2\xa9 1999 J. Marcin Gorycki, 2000-2009 Others",
 			       "license", license,
 			       "website-label", _("GNOME Games web site"),
 			       "authors", authors,
