@@ -24,18 +24,28 @@
  */
 
 #include <config.h>
-#include <gnome.h>
-#include <glib/gi18n.h>
+#include <stdlib.h>
+
 #include <string.h>
-/*#include <gst/gst.h>*/
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
+
+#include <libgames-support/games-clock.h>
+#include <libgames-support/games-conf.h>
+#include <libgames-support/games-frame.h>
+#include <libgames-support/games-help.h>
+#include <libgames-support/games-runtime.h>
+#include <libgames-support/games-scores.c>
+#include <libgames-support/games-scores-dialog.h>
+#include <libgames-support/games-stock.h>
+
+#ifdef WITH_SMCLIENT
+#include <libgames-support/eggsmclient.h>
+#endif /* WITH_SMCLIENT */
 
 #include "minefield.h"
-#include <games-clock.h>
-#include <games-frame.h>
-#include <games-scores.c>
-#include <games-scores-dialog.h>
-#include <games-stock.h>
-#include <games-conf.h>
 
 #define APP_NAME "gnomine"
 #define APP_NAME_LONG N_("Mines")
@@ -77,6 +87,7 @@ gint fsize = -1;
 gboolean use_question_marks = TRUE;
 gboolean use_overmine_warning = TRUE;
 gboolean use_autoflag = FALSE;
+gboolean game_paused = FALSE;
 
 GtkAction *hint_action;
 GtkAction *fullscreen_action;
@@ -86,17 +97,11 @@ GtkAction *resume_action;
 
 /*GstElement *sound_player;*/
 
-static const GamesScoresCategory scorecats[] = { {"Small", N_("Small")},
-{"Medium", N_("gnomine|Medium")},
-{"Large", N_("Large")},
-{"Custom", N_("Custom")},
-GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "Small",
-  APP_NAME,
-  GAMES_SCORES_STYLE_TIME_ASCENDING
+static const GamesScoresCategory scorecats[] = {
+  {"Small",  NC_("board size", "Small")  },
+  {"Medium", NC_("board size", "Medium") },
+  {"Large",  NC_("board size", "Large")  },
+  {"Custom", NC_("board size", "Custom") }
 };
 
 GamesScores *highscores;
@@ -121,11 +126,12 @@ image_widget_setup (char *name)
 {
   GtkWidget *image = NULL;
   char *filename = NULL;
+  const char *dname;
 
   image = gtk_image_new ();
-  filename = gnome_program_locate_file (NULL,
-					GNOME_FILE_DOMAIN_APP_PIXMAP, name,
-					TRUE, NULL);
+  dname = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
+  filename = g_build_filename (dname, name, NULL);
+
   if (filename != NULL)
     gtk_image_set_from_file (GTK_IMAGE (image), filename);
 
@@ -216,7 +222,8 @@ show_scores (gint pos, gboolean endofgame)
 				       pos);
       message = g_strdup_printf ("<b>%s</b>\n\n%s",
 				 _("Congratulations!"),
-				 _("Your score has made the top ten."));
+				 pos == 1 ? _("Your score is the best!") :
+                                 _("Your score has made the top ten."));
       games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
 				       message);
       g_free (message);
@@ -262,7 +269,7 @@ new_game (void)
 
   /* get window size and mine square size (gtk_minefield_restart() may change it) */
   gtk_window_get_size (GTK_WINDOW (window), &width, &height);
-  size = mf->minesize;
+  size = mf->minesizepixels;
   w_diff = width - mfield->allocation.width;
   h_diff = height - mfield->allocation.height;
 
@@ -283,7 +290,7 @@ new_game (void)
   set_flabel (GTK_MINEFIELD (mfield));
 
   gtk_action_set_visible (pause_action, TRUE);
-  gtk_action_set_visible (resume_action, FALSE);    
+  gtk_action_set_visible (resume_action, FALSE);
   gtk_widget_hide (resume_container);
   gtk_widget_show (mfield_container);
 }
@@ -341,7 +348,12 @@ pause_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
     games_clock_stop (GAMES_CLOCK (clk));
 
     gtk_action_set_visible (pause_action, FALSE);
+    gtk_action_set_sensitive (pause_action, FALSE);
+
     gtk_action_set_visible (resume_action, TRUE);
+    gtk_action_set_sensitive (resume_action, TRUE);
+
+    game_paused = TRUE;
   }
 }
 
@@ -354,7 +366,11 @@ resume_game_cb (GtkButton * widget, gpointer data)
   games_clock_start (GAMES_CLOCK (clk));
 
   gtk_action_set_visible (pause_action, TRUE);
+  gtk_action_set_sensitive(pause_action, TRUE);
   gtk_action_set_visible (resume_action, FALSE);
+  gtk_action_set_sensitive(resume_action, FALSE);
+
+  game_paused = FALSE;
 }
 
 static void
@@ -630,6 +646,23 @@ window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
   return FALSE;
 }
 
+
+static void
+pause_key_callback(GtkWidget *widget, GdkEventKey *event,
+gpointer data )
+{
+
+  if(event->keyval == GDK_Pause)
+  {
+    if(game_paused)
+      resume_game_cb(NULL, NULL); // Resume the game
+    else
+      pause_callback(NULL, NULL, NULL); // Pause the game
+  }
+			
+}
+
+
 static void
 create_preferences (void)
 {
@@ -643,6 +676,8 @@ create_preferences (void)
   GtkWidget *overmine_toggle;
   GtkWidget *xentry;
   GtkWidget *yentry;
+  GSList *group;
+  int i;
 
   table = gtk_table_new (3, 2, FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (table), 5);
@@ -653,41 +688,20 @@ create_preferences (void)
 
   vbox = gtk_vbox_new (FALSE, 6);
 
-  button = gtk_radio_button_new_with_label (NULL, _("Small"));
-  if (fsize == 0)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
-		    GINT_TO_POINTER (0));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+  group = NULL;
+  for (i = 0; i < G_N_ELEMENTS (scorecats); ++i) {
+    button = gtk_radio_button_new_with_label (group, g_dpgettext2 (NULL, "board size", scorecats[i].name));
+    if (fsize == i) {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
+    }
 
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)),
-     Q_ ("gnomine|Medium"));
-  if (fsize == 1)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
-		    GINT_TO_POINTER (1));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    g_signal_connect (GTK_OBJECT (button), "clicked",
+                      G_CALLBACK (size_radio_callback),
+                      GINT_TO_POINTER (i));
+    gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), _("Large"));
-  if (fsize == 2)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
-		    GINT_TO_POINTER (2));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
-
-  button = gtk_radio_button_new_with_label
-    (gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), _("Custom"));
-  if (fsize == 3)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-  g_signal_connect (GTK_OBJECT (button), "clicked",
-		    GTK_SIGNAL_FUNC (size_radio_callback),
-		    GINT_TO_POINTER (3));
-  gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (button));
+  }
 
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
@@ -707,7 +721,7 @@ create_preferences (void)
 
   mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX * YSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (mentry), "value-changed",
-		    GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
+		    G_CALLBACK (nmines_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (mentry), nmines);
   gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, 0, 0, 0, 0);
   fix_nmines (xsize, ysize);
@@ -720,7 +734,7 @@ create_preferences (void)
 
   xentry = gtk_spin_button_new_with_range (XSIZE_MIN, XSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (xentry), "value-changed",
-		    GTK_SIGNAL_FUNC (xsize_spin_cb), NULL);
+		    G_CALLBACK (xsize_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (xentry), xsize);
   gtk_table_attach (GTK_TABLE (table2), xentry, 1, 2, 0, 1, 0, 0, 0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), xentry);
@@ -732,7 +746,7 @@ create_preferences (void)
 
   yentry = gtk_spin_button_new_with_range (YSIZE_MIN, YSIZE_MAX, 1);
   g_signal_connect (GTK_OBJECT (yentry), "value-changed",
-		    GTK_SIGNAL_FUNC (ysize_spin_cb), NULL);
+		    G_CALLBACK (ysize_spin_cb), NULL);
   gtk_spin_button_set_value (GTK_SPIN_BUTTON (yentry), ysize);
   gtk_table_attach (GTK_TABLE (table2), yentry, 1, 2, 1, 2, 0, 0, 0, 0);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label2), yentry);
@@ -742,27 +756,33 @@ create_preferences (void)
   gtk_table_attach (GTK_TABLE (table), cframe, 1, 2, 0, 1, GTK_FILL, GTK_FILL,
 		    0, 0);
 
+  frame = games_frame_new(_("Flags"));
+
   question_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"I'm not sure\" flags"));
   g_signal_connect (GTK_OBJECT (question_toggle), "toggled",
-		    GTK_SIGNAL_FUNC (use_question_toggle_cb), NULL);
+		    G_CALLBACK (use_question_toggle_cb), NULL);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (question_toggle),
 				use_question_marks);
   gtk_widget_show (question_toggle);
 
-  gtk_table_attach_defaults (GTK_TABLE (table), question_toggle, 0, 2, 1, 2);
+  gtk_container_add (GTK_CONTAINER (frame), question_toggle);
 
+  gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 2, 1, 2);
+
+  frame = games_frame_new(_("Warnings"));
 
   overmine_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"Too many flags\" warning"));
   g_signal_connect (GTK_OBJECT (overmine_toggle), "toggled",
-		    GTK_SIGNAL_FUNC (use_overmine_toggle_cb), NULL);
+		    G_CALLBACK (use_overmine_toggle_cb), NULL);
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (overmine_toggle),
 				use_overmine_warning);
   gtk_widget_show (overmine_toggle);
 
-  gtk_table_attach_defaults (GTK_TABLE (table), overmine_toggle, 0, 2, 2, 3);
+  gtk_container_add (GTK_CONTAINER (frame), overmine_toggle);
 
+  gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 2, 2, 3);
 
   pref_dialog = gtk_dialog_new_with_buttons (_("Mines Preferences"),
 					     GTK_WINDOW (window),
@@ -786,6 +806,7 @@ create_preferences (void)
   gtk_widget_show_all (GTK_WIDGET (table));
 }
 
+
 static void
 preferences_callback (void)
 {
@@ -797,7 +818,7 @@ preferences_callback (void)
 static void
 help_callback (void)
 {
-  gnome_help_display ("gnomine.xml", NULL, NULL);
+  games_help_display (window, "gnomine", NULL);
 }
 
 const GtkActionEntry actions[] = {
@@ -875,45 +896,50 @@ create_ui_manager (const gchar * group)
   return ui_manager;
 }
 
+#ifdef WITH_SMCLIENT
 static int
-save_state (GnomeClient * client,
-	    gint phase,
-	    GnomeRestartStyle save_style,
-	    gint shutdown,
-	    GnomeInteractStyle interact_style,
-	    gint fast, gpointer client_data)
+save_state_cb (EggSMClient *client,
+	    GKeyFile* keyfile,
+	    gpointer client_data)
 {
   char *argv[20];
-  int i = 0, j;
+  int argc = 0, j;
   gint xpos, ypos;
 
   gdk_window_get_origin (window->window, &xpos, &ypos);
 
-  argv[i++] = (char *) client_data;
-  argv[i++] = "-x";
-  argv[i++] = g_strdup_printf ("%d", xsize);
-  argv[i++] = "-y";
-  argv[i++] = g_strdup_printf ("%d", ysize);
-  argv[i++] = "-n";
-  argv[i++] = g_strdup_printf ("%d", nmines);
-  argv[i++] = "-f";
-  argv[i++] = g_strdup_printf ("%d", fsize);
-  argv[i++] = "-a";
-  argv[i++] = g_strdup_printf ("%d", xpos);
-  argv[i++] = "-b";
-  argv[i++] = g_strdup_printf ("%d", ypos);
+  argv[argc++] = g_get_prgname ();
+  argv[argc++] = "-x";
+  argv[argc++] = g_strdup_printf ("%d", xsize);
+  argv[argc++] = "-y";
+  argv[argc++] = g_strdup_printf ("%d", ysize);
+  argv[argc++] = "-n";
+  argv[argc++] = g_strdup_printf ("%d", nmines);
+  argv[argc++] = "-f";
+  argv[argc++] = g_strdup_printf ("%d", fsize);
+  argv[argc++] = "-a";
+  argv[argc++] = g_strdup_printf ("%d", xpos);
+  argv[argc++] = "-b";
+  argv[argc++] = g_strdup_printf ("%d", ypos);
 
-  gnome_client_set_restart_command (client, i, argv);
-  /* i.e. clone_command = restart_command - '--sm-client-id' */
-  gnome_client_set_clone_command (client, 0, NULL);
+  egg_sm_client_set_restart_command (client, argc, (const char **) argv);
 
-  for (j = 2; j < i; j += 2)
+  for (j = 2; j < argc; j += 2)
     g_free (argv[j]);
 
   return TRUE;
 }
-
 
+static gint
+quit_cb (EggSMClient *client,
+         gpointer client_data)
+{
+  gtk_main_quit ();
+
+  return FALSE;
+}
+
+#endif /* WITH_SMCLIENT */
 
 static int xpos = -1, ypos = -1;
 
@@ -945,7 +971,6 @@ sound_init (int *argcp, char **argvp[])
 int
 main (int argc, char *argv[])
 {
-  GnomeProgram *program;
   GOptionContext *context;
 
   GtkWidget *all_boxes;
@@ -954,9 +979,13 @@ main (int argc, char *argv[])
   GtkWidget *box;
   GtkWidget *label;
   GtkWidget *face_box;
-  GnomeClient *client;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
+  gboolean retval;
+  GError *error = NULL;
+#ifdef WITH_SMCLIENT
+  EggSMClient *sm_client;
+#endif /* WITH_SMCLIENT */
 
   static const GOptionEntry options[] = {
     {"width", 'x', 0, G_OPTION_ARG_INT, &xsize, N_("Width of grid"), N_("X")},
@@ -973,33 +1002,52 @@ main (int argc, char *argv[])
     {NULL}
   };
 
+  if (!games_runtime_init ("gnomine"))
+    return 1;
+
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
-  context = g_option_context_new ("");
+  context = g_option_context_new (NULL);
+#if GLIB_CHECK_VERSION (2, 12, 0)
+  g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
+  g_option_context_add_group (context, gtk_get_option_group (TRUE));
+#ifdef WITH_SMCLIENT
+  g_option_context_add_group (context, egg_sm_client_get_option_group ());
+#endif /* WITH_SMCLIENT */
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
-  program = gnome_program_init (APP_NAME, VERSION, LIBGNOMEUI_MODULE,
-				argc, argv,
-				GNOME_PARAM_APP_DATADIR, DATADIR,
-				GNOME_PARAM_GOPTION_CONTEXT, context, NULL);
+  retval = g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
+  if (!retval) {
+    g_print ("%s", error->message);
+    g_error_free (error);
+    exit (1);
+  }
+
+  g_set_application_name (_(APP_NAME_LONG));
     
   games_conf_initialise (APP_NAME);
 
-  highscores = games_scores_new (&scoredesc);
-
-  /* sound_init (&argc, &argv); */
+  highscores = games_scores_new (APP_NAME,
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 "board size", NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_TIME_ASCENDING);
 
   g_signal_connect (games_conf_get_default (), "value-changed",
                     G_CALLBACK (conf_value_changed_cb), NULL);
 
   gtk_window_set_default_icon_name ("gnome-mines");
-  client = gnome_master_client ();
-  g_signal_connect (G_OBJECT (client), "save_yourself",
-		    G_CALLBACK (save_state), argv[0]);
+
+#ifdef WITH_SMCLIENT
+  sm_client = egg_sm_client_get ();
+  g_signal_connect (sm_client, "save-state",
+		    G_CALLBACK (save_state_cb), NULL);
+  g_signal_connect (sm_client, "quit",
+                    G_CALLBACK (quit_cb), NULL);
+#endif /* WITH_SMCLIENT */
+
 
   if (xsize == -1)
     xsize = games_conf_get_integer (KEY_GEOMETRY_GROUP, KEY_XSIZE, NULL);
@@ -1023,7 +1071,8 @@ main (int argc, char *argv[])
   gtk_rc_parse_string
     ("style \"gnomine\" { GtkButton::interior-focus = 0 } class \"GtkButton\" style \"gnomine\"");
 
-  window = gnome_app_new (APP_NAME, APP_NAME_LONG);
+  window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+  gtk_window_set_title (GTK_WINDOW (window), _(APP_NAME_LONG));
     
   games_conf_add_window (GTK_WINDOW (window), NULL);
 
@@ -1038,9 +1087,14 @@ main (int argc, char *argv[])
   g_signal_connect (G_OBJECT (window), "window_state_event",
 		    G_CALLBACK (window_state_callback), NULL);
 
+  // For pause/resume with the keyboard pause key
+  g_signal_connect (G_OBJECT (window), "key_press_event", 
+                    G_CALLBACK (pause_key_callback), NULL); 
+
   all_boxes = gtk_vbox_new (FALSE, 0);
 
-  gnome_app_set_contents (GNOME_APP (window), all_boxes);
+  gtk_container_add (GTK_CONTAINER (window), all_boxes);
+
   ui_manager = create_ui_manager ("GnomineActions");
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -1061,11 +1115,11 @@ main (int argc, char *argv[])
   face_box = gtk_vbox_new (FALSE, 5);
   gtk_container_add (GTK_CONTAINER (mbutton), face_box);
 
-  pm_win = image_widget_setup ("gnomine/face-win.svg");
-  pm_sad = image_widget_setup ("gnomine/face-sad.svg");
-  pm_smile = image_widget_setup ("gnomine/face-smile.svg");
-  pm_cool = image_widget_setup ("gnomine/face-cool.svg");
-  pm_worried = image_widget_setup ("gnomine/face-worried.svg");
+  pm_win = image_widget_setup ("face-win.svg");
+  pm_sad = image_widget_setup ("face-sad.svg");
+  pm_smile = image_widget_setup ("face-smile.svg");
+  pm_cool = image_widget_setup ("face-cool.svg");
+  pm_worried = image_widget_setup ("face-worried.svg");
 
   gtk_box_pack_start (GTK_BOX (face_box), pm_win, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (face_box), pm_sad, FALSE, FALSE, 0);
@@ -1117,7 +1171,7 @@ main (int argc, char *argv[])
   gtk_box_pack_start (GTK_BOX (box), gtk_hseparator_new (), FALSE, FALSE, 0);
 
   status_box = gtk_hbox_new (TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (box), status_box, FALSE, FALSE, GNOME_PAD);
+  gtk_box_pack_start (GTK_BOX (box), status_box, FALSE, FALSE, 8);
 
   flabel = gtk_label_new ("");
   gtk_box_pack_start (GTK_BOX (status_box), flabel, FALSE, FALSE, 0);
@@ -1153,9 +1207,7 @@ main (int argc, char *argv[])
     
   games_conf_shutdown ();
 
-  gnome_accelerators_sync ();
-
-  g_object_unref (program);
+  games_runtime_shutdown ();
 
   return 0;
 }
